summaryrefslogtreecommitdiffstats
path: root/kword/KWFactory.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 19:55:40 -0600
commit73ff676f11662d6178c8854a7832ebffe2ae409d (patch)
tree9e89ea7d87940087d2d3c5db9b378ef989dd1346 /kword/KWFactory.h
parentc2ba2f56121c21a762619faf195e8332ef5b224f (diff)
downloadkoffice-73ff676f11662d6178c8854a7832ebffe2ae409d.tar.gz
koffice-73ff676f11662d6178c8854a7832ebffe2ae409d.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'kword/KWFactory.h')
-rw-r--r--kword/KWFactory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kword/KWFactory.h b/kword/KWFactory.h
index 30d69cf9..028756db 100644
--- a/kword/KWFactory.h
+++ b/kword/KWFactory.h
@@ -22,7 +22,7 @@
#include <KoFactory.h>
-class KAboutData;
+class TDEAboutData;
class KWFactory : public KoFactory
{
@@ -34,14 +34,14 @@ public:
virtual KParts::Part* createPartObject( TQWidget * = 0, const char * = 0, TQObject* parent = 0, const char* name = 0, const char* classname = "KoDocument", const TQStringList &args = TQStringList() );
- static KInstance* instance();
+ static TDEInstance* instance();
- // _Creates_ a KAboutData but doesn't keep ownership
- static KAboutData* aboutData();
+ // _Creates_ a TDEAboutData but doesn't keep ownership
+ static TDEAboutData* aboutData();
private:
- static KInstance* s_instance;
- static KAboutData* s_aboutData;
+ static TDEInstance* s_instance;
+ static TDEAboutData* s_aboutData;
};
#endif